@@ -16,7 +16,7 @@ class TinyMCEAdminMixin(object):
     class Media:
         js = [
             static('grappelli/tinymce/jscripts/tiny_mce/tiny_mce.js'),
-            static('/static/td_cms/javascripts/vendor/tinymce_setup.js'),
+            static('td_cms/javascripts/vendor/tinymce_setup.js'),
         ]
 
 
